//+------------------------------------------------------------------+
//|                                       Close_Muliple_Positions.mq4|
//+------------------------------------------------------------------+
#property copyright "Tamir Hacham"
#property link      "tamir58@bezeqint.net"

// Inputs   
extern int PeriodMA = 5;
extern int Trade_Enable = 1; 
extern int Maximum_Positions = 3;
extern double Slippage = 3; 
extern double Lots = 0.1; 
extern double TakeProfit = 100; 

static bool Trend_is_Up, Trend_is_Down;
static int Long_Positions_Count, Short_Positions_Count, Total_Trades;
static bool LONG, LONG_1, LONG_2, Close_Long, Long_Position_Open;
static bool SHORT, SHORT_1, SHORT_2, Close_Short, Short_Position_Open;

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
{
   if (Maximum_Positions > 3) Maximum_Positions = 3;
   
   Total_Trades = 1;
   Long_Positions_Count = 0;
   Short_Positions_Count = 0;
   
   Trend_is_Up = True;
   Trend_is_Down = False;
   Close_Long = False;
   Long_Position_Open = False;

   Close_Short = False;
   Short_Position_Open = False;

   return(0);
}
  

//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
   return(0);
  }
  
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
int start()
{
   static int i, cnt, limit, ticket, total, magic_number;

//---- Trend Variables Initialization ----//
   
   double diMA1=iMA(NULL,0,PeriodMA  ,0,0,PRICE_CLOSE,1);
   double diMA2=iMA(NULL,0,PeriodMA+13,0,0,PRICE_CLOSE,1);
   double diMA3=iMA(NULL,0,PeriodMA+26,0,0,PRICE_CLOSE,1);

//---- Trading Criteria ----//

   Trend_is_Up = diMA1>diMA3; //(Close[1]>diMA3);
   Trend_is_Down = diMA1<diMA3; //(Close[1]<diMA3);
   
   {
      LONG    = (iClose(NULL, 0, 1)>=diMA1 && iClose(NULL, 0, 2)<diMA1);
      LONG_1  = (iClose(NULL, 0, 1)>=diMA2 && iClose(NULL, 0, 2)<diMA2);
      LONG_2  = (iClose(NULL, 0, 1)>=diMA3 && iClose(NULL, 0, 2)<diMA3);
   }
   {
      SHORT    = (iClose(NULL, 0, 1)<=diMA1 && iClose(NULL, 0, 2)>diMA1);
      SHORT_1  = (iClose(NULL, 0, 1)<=diMA2 && iClose(NULL, 0, 2)>diMA2);
      SHORT_2  = (iClose(NULL, 0, 1)<=diMA3 && iClose(NULL, 0, 2)>diMA3);
   }

   //--- Close Position Criteria ---//
   Close_Long =  (iClose(NULL, 0, 1)<=diMA3 && iClose(NULL, 0, 2)>diMA3);
   Close_Short = (iClose(NULL, 0, 1)>=diMA3 && iClose(NULL, 0, 2)<diMA3);
  
   //--- Closing Positions ---//
   total=OrdersTotal();
   if (total > 0)
   {
      for(cnt=0; cnt < total; cnt++)
      {
         OrderSelect(cnt, SELECT_BY_POS, MODE_TRADES);
         if (Close_Long)
         {
            if(OrderType() == OP_BUY &&   // check for opened long position 
               OrderSymbol() == Symbol())  // check for symbol
            {// it should be closed
               OrderClose(OrderTicket(),OrderLots(),Bid,3,Violet); // close position
               //return(0); // exit
            }
         }
        else if (Close_Short)
         {
            if(OrderType() == OP_SELL &&   // check for opened short position 
               OrderSymbol() == Symbol())  // check for symbol
            {// it should be closed
               OrderClose(OrderTicket(),OrderLots(),Ask,3,Violet); // close position
               //return(0); // exit
            }
         }
         else if (cnt == total-1)
         {
            Long_Positions_Count = 0;
            Long_Position_Open = False;
            Short_Positions_Count = 0;
            Short_Position_Open = False;
            return(0);
         }
      }   
   }         

   total=OrdersTotal();
   if(total<Maximum_Positions && Trade_Enable == 1) // check if any position was opened
   {
      if (LONG) // Long Trades
      {
         if (Long_Positions_Count<Maximum_Positions)
         {
            //First position
            if (LONG_1) //is going up
            {
               magic_number = Long_Positions_Count*100 + 11; // 111
               ticket=OrderSend(Symbol(),OP_BUY,Lots,Ask,3,0,Ask+TakeProfit*Point,"Trend Follower",magic_number,0,Blue);
               if(ticket>0)
               {
                  if(OrderSelect(ticket,SELECT_BY_TICKET,MODE_TRADES)) 
                     Print("BUY order opened : ",OrderOpenPrice());
                     Long_Positions_Count ++;
                     Total_Trades ++;
                     Long_Position_Open = True;
                     LONG_1 = False;
                     LONG_2 = True;
               }
               else 
               {
                  Print("Error opening BUY order : ",GetLastError()); 
                  //return(0);
               }   
            }
            //More Long positions
            else if (LONG_2)// Still going up
            {
               magic_number = Long_Positions_Count*100 + 12; // 112
               ticket=OrderSend(Symbol(),OP_BUY,Lots,Ask,3,0,Ask+TakeProfit*Point,"Trend Follower",magic_number,0,Blue);
               if(ticket>0)
               {
                  if(OrderSelect(ticket,SELECT_BY_TICKET,MODE_TRADES)) 
                     Print("BUY order opened : ",OrderOpenPrice());
                     Long_Positions_Count ++;
                     Total_Trades ++;
                     Long_Position_Open = True;
               }
               else 
               {
                  Print("Error opening BUY order : ",GetLastError()); 
                  //return(0);
               }
            }   
         }
      }  // End of Long Trades
      else if (SHORT) // Short Trades
      {
         if (Short_Positions_Count<Maximum_Positions)
         {
            //First position
            if (SHORT_1) //is going down
            {
               magic_number = Short_Positions_Count*100 + 21; // 121
               ticket=OrderSend(Symbol(),OP_SELL,Lots,Bid,Slippage,0,Bid-TakeProfit*Point,"Trend Follower",magic_number,0,Red);
               if(ticket>0)
               {
                  if(OrderSelect(ticket,SELECT_BY_TICKET,MODE_TRADES)) 
                     Print("SELL order opened : ",OrderOpenPrice());
                     Short_Positions_Count ++;
                     Total_Trades ++;
                     Short_Position_Open = True;
                     SHORT_1 = False;
                     SHORT_2 = True;
               }
               else 
               {
                  Print("Error opening SELL order : ",GetLastError()); 
                  //return(0);
               }
            }      
            //More Short positions
            else if (SHORT_2)// Still going down
            {
               magic_number = Short_Positions_Count*100 + 22; // 122
               ticket=OrderSend(Symbol(),OP_SELL,Lots,Bid,Slippage,0,Bid-TakeProfit*Point,"Trend Follower",magic_number,0,Red);
               if(ticket>0)
                 {
                  if(OrderSelect(ticket,SELECT_BY_TICKET,MODE_TRADES)) 
                     Print("SELL order opened : ",OrderOpenPrice());
                     Short_Positions_Count ++;
                     Total_Trades ++;
                     Short_Position_Open = True;
                 }
               else 
               {
                  Print("Error opening SELL order : ",GetLastError()); 
                  //return(0);
               }   
            }
         }   
      } // End Short Trades        
      
   }
//---
   return(0);
}

